"use strict"

var Webapi = {

    exec: function (func, arg, callback)
    {
        $.ajaxSetup({ cache: false })  //edge対策

        $.getJSON("/webapi/" + func, arg, callback)
        .fail(function ()
        {
            Dialog.alert("通信に失敗しました。デバイスの通信環境やMediaIndexが起動中かどうか確認してください。")
        })
    },

    getTable: function (sql, callback)
    {
        this.exec("GetTable", { sql: sql }, callback)
    },

    //SQL文で、文字列を指定する場合のエスケープ
    sqlEncode: function (text)
    {
        return text.split("'").join("''")
    },

    //SQLのlike文のエスケープ
    //like文を使う場合は「escape '^'」を追加してください
    sqlLikeEncode: function (text)
    {
        text = this.sqlEncode(text)

        text = text.split("^").join("^^")
        text = text.split("_").join("^_")
        text = text.split("%").join("^%")

        return text;
    },

    //DateTimeをXDateに変換
    convertXDate: function (time)
    {
        time = time / 10000 - 62135596800000	//ナノ秒をミリ秒にして、1970年分引く
        var timezone = (new Date()).getTimezoneOffset() * 60 * 1000	//タイムゾーン
        return new XDate(time + timezone)
    },

    //XDateをDateTimeに変換
    convertDateTime: function (xdate)
    {
        var timezone = (new Date()).getTimezoneOffset() * 60 * 1000
        return (xdate.getTime() - timezone + 62135596800000) * 10000
    },

    //再生
    play: function (id, path, callback)
    {
        var self = this

        $.ajaxSetup({ cache: false });  //edge,IE対策

        $.getJSON("http://localhost:30001/webapi/Play", { path: path }, function (ret)
        {
            if (ret.code == 0)
                self.setPlayData(id, callback)
            else
                Dialog.alert("再生に失敗しました。\n理由 : " + ret.message)
        })
        .fail(function ()
        {
            Dialog.alert("通信に失敗しました。ローカルでMediaIndexが起動しているか確認してください。Androidの場合は、設定で再生ボタンをダウンロードにしてください。")
        })
    },

    //再生回数の登録
    setPlayData: function (id, callback)
    {
        this.exec("SetPlayData", { id: id }, function (ret)
        {
            if (ret.code == 0)
                callback()
            else
                Dialog.alert("再生回数の登録に失敗しました。\n理由 : " + ret.message)
        })
    },

    //DBのタグを配列に変換
    getTagArr: function (tag)
    {
        var list = tag.match(/<(.+?)>/g)
        var arr = []

        if (list != null)
            arr = list.map(function (s) { return s.substring(1, s.length - 1) })

        return arr
    },

    getTimeString: function (datetime)
    {
        if (datetime == 0)
            return "---"
        else
        {
            var time = this.convertXDate(datetime)
            return time.toString("yy/MM/dd HH:mm:ss")
        }
    },

    //メディアタイプ別の長さ表示
    getLengthString: function (type, length)
    {
        var ret = "---";
        if (length != -1)
        {
            var category = type.split("/")
            if (category.length > 0)

                switch (category[0])
                {
                    case "video":
                        {
                            var min = Math.floor(length / 60 % 60)
                            var sec = length % 60
                            ret = "{0}:{1}:{2}".format(
                                Math.floor(length / 3600),
                                ("00" + min).substr(-2),
                                ("00" + sec).substr(-2))
                            break
                        }
                    case "book":
                        ret = "{0} ページ".format(length)
                        break
                    default:
                        ret = length.toString()
                        break
                }
        }
        return ret
    },

    //ファイルサイズ表示
    getSizeString: function (size)
    {
        if (size < 1024)
            return 1 + " KB"
        else if (size < 1048576)
            return (size / 1024).toFixed(1) + " KB"
        else if (size < 1073741824)
            return (size / 1048576).toFixed(1) + " MB"
        else
            return (size / 1073741824).toFixed(1) + " GB"
    },

    //フォルダ取得
    getDir: function (path)
    {
        var dir = path.substring(0, path.lastIndexOf('\\'))

        if (dir.length == 2)
            dir += '\\'	//ルートの場合の処理

        return dir
    },

    //フォルダ取得
    getFileName: function (path)
    {
        return path.substring(path.lastIndexOf('\\') + 1, path.length)
    }
}
